#
# spec file for package libzen
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover	0
Name:           libzen
Version:        0.4.41
Release:        1.4
Summary:        C++ utility library
License:        Zlib
Group:          Development/Libraries/C and C++
URL:            https://github.com/MediaArea/ZenLib
Source:         https://mediaarea.net/download/source/%{name}/%{version}/%{name}_%{version}.tar.xz
Source1:        baselibs.conf
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig

%description
ZenLib is a C++ utility library. It includes classes for handling
strings, configuration, bit streams, threading, translation
and cross-platform operating system functions.

%package -n %{name}%{sover}
Summary:        The ZenLib C++ utility library
Group:          System/Libraries

%description -n %{name}%{sover}
ZenLib is a C++ utility library. It includes classes for handling
strings, configuration, bit streams, threading, translation
and cross-platform operating system functions.

%package -n libzen-devel
Summary:        Include files to develop for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name}%{sover} = %{version}

%description -n libzen-devel
Include files and mandatory libraries to develop
for %{name}.

%prep
%setup -q -n ZenLib
sed -i 's/\r$//' *.txt

%build
# generate docs
pushd Source/Doc
    doxygen -u 2> /dev/null
    doxygen Doxyfile
popd

pushd Project/GNU/Library
    autoreconf -fiv
    %configure --enable-shared --disable-static
    make %{?_smp_mflags}
popd

%install
pushd Project/GNU/Library
%make_install
popd

sed -i -e '/^Libs_Static/d' \
    %{buildroot}%{_libdir}/pkgconfig/%{name}.pc
rm %{buildroot}%{_libdir}/%{name}.la

%fdupes %{buildroot}/%{_prefix}

%post   -n %{name}%{sover} -p /sbin/ldconfig
%postun -n %{name}%{sover} -p /sbin/ldconfig

%files -n %{name}%{sover}
%defattr(-,root,root,-)
%doc *.txt
%{_libdir}/libzen.so.%{sover}
%{_libdir}/libzen.so.%{sover}.*

%files -n libzen-devel
%defattr(-,root,root,-)
%doc Source/Doc/Documentation.html
%doc Doc/*
%{_includedir}/ZenLib/
%{_libdir}/libzen.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Fri Apr  7 2023 zero mind <zeromind@gmx.com>
- update to 0.4.41:
  * BitStream_LE: Fix use of uninitialised values
* Fri Dec 23 2022 Dirk Müller <dmueller@suse.com>
- update to 0.4.40:
  + BitStream_Fast: Resize()
  + C++11 min everywhere
  x Remove the bitcode generation in iOS build (no more supported by
    Apple)
  x Fix incompatibilities with some compilers
* Tue Apr 13 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.39
  * Threads: avoid critical sections lockers when possible
  * HTTP_Client: Try UTF8 first for network data
  * Threads: call to non thread-safe time related functions
    (gmtime, localtime) are avoided as much as possible
  * Threads: update non Windows binding (was not complete)
  * Fix crash on some ARMv7 devices
* Tue Aug 25 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.4.38:
  * Ztring: some date conversion methods were not thread safe
  * Miscellaneous fixes
* Thu Dec 21 2017 aloisio@gmx.com
- Update to version 0.4.37
  * Restore CMake 2.8 compatibility
  * Fix CSV loading with old Mac-style carriage return
  * Fix a mutex dead lock with some thread class calls
  version 0.4.36
  * pkg-config and CMake improvements
  * Correct handle of load from CSV with quotes
  * Mageia 6, Fedora 26, Debian 9 compatibility
  version 0.4.35
  * Enable large files support in CMake project
  * Visual Studio 2017 project files
  version 0.4.34
  * Minor performance optimizations and cleanup (Thanks to Pavel Pimenov)
  * Add PKGBUILD file for Arch Linux
  * CMake improvements (Thanks to evpobr)
  * Build scripts improvements
  * Fix for Ubuntu 16.10
  * Change lib name for Fedora and RHEL/CentOS to follow their guidelines
  * Update Visual Studio project files (support of 32-bit CPU without SSE)
  version 0.4.33
  * File::Open(): using now FILE_APPEND_DATA on windows when append mode is requested
  * File::Open(): accept file names with * and ? characters on non-Windows platforms
  * Better MinGW and CygWin compatibility
  * autogen.sh: Adding missing shebang
  * Dir/Create: create the parents directory if not existing
  version 0.4.32
  * Ztring::From_UTF8() was not handling 4 bytes UTF8 codes correctly
- Use new source URL
- Spec cleanup
* Sat Mar  4 2017 jengelh@inai.de
- Rename %%soname to %%sover to reflects its actual use.
- Drop export CFLAGS because %%configure does that already.
- Use --disable-static in place of building and later removing .a.
- Limit scope of %%fdupes to partition.
- Clean up descriptions.
* Sun Feb 26 2017 aloisio@gmx.com
- Added baselibs.conf as source file
* Sun Feb 26 2017 davejplater@gmail.com
- Relicensed to Zlib following Fedora.
* Sun Feb 26 2017 aloisio@gmx.com
- Update to version 0.4.31
  * BigEndian2float16() was buggy
  * <new> is possible only with C++
  version 0.4.30
  * New MemoryUtils.h functions for SSE2 memcpy
  * Ztring::From_Unicode(const wchar_t S)
  * CMake: scripts improvements, thanks to Ivan Romanov
- Spec cleanup
* Thu Mar 27 2014 i@margueirte.su
- update version 0.4.29
  * Ztring: Ztring_NoZero option was not correctly implemented
  * File: Write only is not possible with ios_base::out (file is
    truncated) on Linux
  * Dir: Include_Dirs only was not working
  * File: accepts Windows "\\?\" magic value
* Thu Oct  4 2012 i@marguerite.su  
- Update to 0.4.28
  * Removing _T() in order to be compatible with LLVM compiler
  * Ztring: UTF-16 conversion routines crash if the provided string size is odd.
  * GNU: forcing stdc++ at link
* Sat May 19 2012 seife+obs@b1-systems.com
- add autoconf/automake/libtool to buildrequires to fix 12.2 build
* Tue Oct 18 2011 nomail@nomail.com
- Update to 0.4.22
  x #3412495, Ztring: To_UTF8() was working wrong, corrected
    thanks to Andrew Jang
  x #3157308, Ztring::Assign_FromFile(): Memory leak
  + TinyXml updated
  + float16 (on disk) support
  + Ztring: more compatibility with uCLibC
  x BitStream_LE: wrong result if buffer underrun
  + HTTP helpers in Unicode version
  x BitStream Little Endian: count of remaining bits was wrong
  x ZtringList and ZtringListList :: Read(): do not remove pending
    delimiters
  x File Open status: error with Windows return value
* Tue Mar  8 2011 pascal.bleser@opensuse.org
- add baselibs.conf
- update to 0.4.17:
  * BitStream: skip methods improvements
- changes from 0.4.16:
  * BitStream: Peek3()
  * decimal point issues with some specific compilers/OS
  * ZtringList: issues with EOL
  * #3025205, file is not opened if a "?" is in it
* Sat Jul 31 2010 toni@links2linux.de
- update to 0.4.15
* Mon May  3 2010 toni@links2linux.de
- update to 0.4.14
* Fri Apr 16 2010 toni@links2linux.de
- update to 0.4.13
* Tue Mar  9 2010 toni@links2linux.de
- update to 0.4.12
* Sun Feb 21 2010 toni@links2linux.de
- update to 0.4.11
* Mon Jan 11 2010 toni@links2linux.de
- update to 0.4.10
* Fri Nov 20 2009 toni@links2linux.de
- update to 0.4.9
* Fri Oct 30 2009 toni@links2linux.de
- update to 0.4.8
* Tue Oct 27 2009 toni@links2linux.de
- update to 0.4.7
* Tue Oct 13 2009 toni@links2linux.de
- update to 0.4.6
* Fri Apr 17 2009 toni@links2linux.de
- update to 0.4.2
* Sun Apr  5 2009 toni@links2linux.de
- update to 0.4.1
* Sat Apr  4 2009 toni@links2linux.de
- redowngrade to 0.4.0
* Thu Apr  2 2009 toni@links2linux.de
- update to 0.4.1
* Fri Mar 20 2009 toni@links2linux.de
- update to 0.4.0
* Fri Feb 13 2009 toni@links2linux.de
- update to 0.3.8
* Fri Jan 30 2009 toni@links2linux.de
- update to 0.3.7
* Fri Jan 23 2009 toni@links2linux.de
- update to 0.3.6
* Tue Dec  9 2008 toni@links2linux.de
- update to 0.3.5
- docs are now generated with doxygen
* Mon Nov 17 2008 toni@links2linux.de
- added api-doc to devel subpackage
- instead of ZenLib-config now a pkgconfig file is provided
* Mon Dec 10 2007 toni@links2linux.de
- libZenLib and libMediaInfoLib are renamed to libzen and libmediainfo
- install *-config files manually
- added devel-subpackages
- split off from MediaInfo package
